==> ScraperFC-2.3.0.tar.gz: ScraperFC-2.3.0/README.md <==
<p align="center">
  <a href="https://pypi.org/project/ScraperFC/"><img src="https://img.shields.io/pypi/v/scraperfc.svg", alt="pypi version badge"></a>
  <a href="https://pypi.org/project/ScraperFC/"><img src="https://static.pepy.tech/badge/scraperfc" alt="downloads badge"/></a>
  <a href="https://scraperfc.readthedocs.io/en/latest/"><img src="https://readthedocs.org/projects/nrc4d/badge/?version=latest" alt="documentation status badge"/></a>
  <a href="https://github.com/oseymour/ScraperFC"><img src="http://hits.dwyl.com/oseymour/scraperfc.svg?style=flat"></a>
</p>

This is ScraperFC, a Python package that I hope will give more people access to soccer data. Gone are the days of downloading spreadsheets one-by-one, copy-pasting, or entering data into spreadsheets by hand. I try to make ScraperFC as easy-to-use as possible so that anybody with a bit of Python experience can use it.

To install ScraperFC, run ```pip install ScraperFC``` from the command line.

Data can be scraped from the following sources:
* [FBRef](https://fbref.com/en/)
* [Understat](https://understat.com/)
* [FiveThirtyEight](https://projects.fivethirtyeight.com/soccer-predictions/)
* [ClubELO](http://clubelo.com/)
* [Capology](https://www.capology.com/)
* [Transfermarkt](https://www.transfermarkt.us/)

For documentation, head over to the [Read the Docs page](https://scraperfc.readthedocs.io).

For usage examples, look at Examples.ipynb in the top level directory or some of my example analyses in the analytics_examples folder.

I'd love to hear your feedback, bugs you find, or new features you want! The best way is to open an issue on this repository and I can respond to it there. Otherwise, you can reach me via email at osmour043@gmail.com or my Twitter handle is [@owen_seymour](https://twitter.com/owen_seymour).

==> ScraperFC-2.4.0.tar.gz: ScraperFC-2.4.0/README.md <==
<p align="center">
  <img src="https://github.com/oseymour/ScraperFC/blob/main/scraperfc_logo.png?raw=true" alt="ScraperFC logo. The underlined text ScraperFC, where the circle of the p is a soccer ball.">
</p>
<p align="center">
  <a href="https://pypi.org/project/ScraperFC/"><img src="https://img.shields.io/pypi/v/scraperfc.svg", alt="pypi version badge"></a>
  <a href="https://pypi.org/project/ScraperFC/"><img src="https://static.pepy.tech/badge/scraperfc" alt="downloads badge"/></a>
  <a href="https://scraperfc.readthedocs.io/en/latest/"><img src="https://readthedocs.org/projects/nrc4d/badge/?version=latest" alt="documentation status badge"/></a>
  <a href="https://github.com/oseymour/ScraperFC"><img src="http://hits.dwyl.com/oseymour/scraperfc.svg?style=flat"></a>
</p>

This is ScraperFC, a Python package that I hope will give more people access to soccer data. Gone are the days of downloading spreadsheets one-by-one, copy-pasting, or entering data into spreadsheets by hand. I try to make ScraperFC as easy-to-use as possible so that anybody with a bit of Python experience can use it.

To install ScraperFC, run ```pip install ScraperFC``` from the command line.

Data can be scraped from the following sources:
* [FBRef](https://fbref.com/en/)
* [Understat](https://understat.com/)
* [FiveThirtyEight](https://projects.fivethirtyeight.com/soccer-predictions/)
* [ClubELO](http://clubelo.com/)
* [Capology](https://www.capology.com/)
* [Transfermarkt](https://www.transfermarkt.us/)

For documentation, head over to the [Read the Docs page](https://scraperfc.readthedocs.io).

For usage examples, look at Examples.ipynb in the top level directory or some of my example analyses in the analytics_examples folder.

I'd love to hear your feedback, bugs you find, or new features you want! The best way is to open an issue on this repository and I can respond to it there. Otherwise, you can reach me via email at osmour043@gmail.com or my Twitter handle is [@owen_seymour](https://twitter.com/owen_seymour).
